@@ -1,12 +1,15 @@
 # -*- coding: utf-8 -*-
 
+from __future__ import annotations
+
 import contextlib
 import os
 import sys
+from collections.abc import Iterator
 
 
 @contextlib.contextmanager
-def suppress_stdout(suppress: bool = True) -> None:
+def suppress_stdout(suppress: bool = True) -> Iterator[None]:
     with open(os.devnull, mode="w") as devnull:
         stdout = sys.stdout
         if suppress:
