@@ -1,7 +1,11 @@
 # -*- coding: utf-8 -*-
 
+from __future__ import annotations
+
 import logging
+import os
 import sys
+from collections.abc import Mapping
 from typing import Optional, Union
 
 
@@ -34,7 +38,7 @@ def setup_logger(
     format: str = "%(asctime)s %(name)s %(levelname)s: %(message)s",
     force: bool = True,
     stream: bool = True,
-    filename: str = None,
+    filename: Optional[Union[str, bytes, os.PathLike]] = None,
     **kwargs,
 ) -> None:
     handlers = []
@@ -56,3 +60,8 @@ def setup_logger(
             kwargs["force"] = force
 
     logging.basicConfig(**kwargs)
+
+
+def log_dict(_logger: logging.Logger, d: Mapping, sep: str = " = ") -> None:
+    for key, value in d.items():
+        _logger.info(f"{key}{sep}{value}")
